"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateManyToManyTables = void 0;
const model_1 = require("./model");
function generateManyToManyTables(models, mapToDbSchema = false) {
    const manyToManyFields = filterManyToManyRelationFields(models);
    if (manyToManyFields.length === 0) {
        return [];
    }
    return generateTables(manyToManyFields, models, [], mapToDbSchema);
}
exports.generateManyToManyTables = generateManyToManyTables;
function generateTables(manyToManyFields, models, manyToManyTables = [], mapToDbSchema = false) {
    const manyFirst = manyToManyFields.shift();
    if (!manyFirst) {
        return manyToManyTables;
    }
    const manySecond = manyToManyFields.find((field) => field.relationName === manyFirst.relationName);
    if (!manySecond) {
        return manyToManyTables;
    }
    manyToManyTables.push(`Table ${manyFirst === null || manyFirst === void 0 ? void 0 : manyFirst.relationName} {\n` +
        `${generateJoinFields([manyFirst, manySecond], models, mapToDbSchema)}` +
        '\n}');
    return generateTables(manyToManyFields.filter((field) => field.relationName !== manyFirst.relationName), models, manyToManyTables, mapToDbSchema);
}
function generateJoinFields(field, models, mapToDbSchema = false) {
    return field
        .map((field) => joinField(field, models, mapToDbSchema))
        .join('\n');
}
function joinField(field, models, mapToDbSchema = false) {
    var _a;
    const fieldName = mapToDbSchema
        ? ((_a = (0, model_1.getModelByType)(models, field.type)) === null || _a === void 0 ? void 0 : _a.dbName) || field.type
        : field.type;
    return `  ${field.name.toLowerCase()}Id ${getJoinIdType(field, models)} [ref: > ${fieldName}.${field.relationToFields[0]}]`;
}
function getJoinIdType(joinField, models) {
    const joinIdField = models
        .filter((model) => model.name === joinField.type)
        .map((model) => model.fields.find((field) => field.name === joinField.relationToFields[0]))[0];
    return joinIdField.type;
}
function filterManyToManyRelationFields(models) {
    return models
        .map((model) => model.fields
        .filter((field) => {
        var _a, _b;
        return field.relationName &&
            field.isList &&
            ((_a = field.relationFromFields) === null || _a === void 0 ? void 0 : _a.length) === 0 &&
            ((_b = field.relationToFields) === null || _b === void 0 ? void 0 : _b.length);
    })
        .map((field) => field))
        .flat();
}
